@@ -44,6 +44,7 @@ class Config
         bool bUpdateCache;
         bool bSaveSerials;
         bool bPlatformDetection;
+        bool bShowWishlist;
         std::string sGameRegex;
         std::string sDirectory;
         std::string sCacheDirectory;
@@ -65,10 +66,11 @@ class Config
         std::string sLanguagePackSubdir;
         std::string sDLCSubdir;
         std::string sGameSubdir;
-	std::string sLanguagePriority;
-	std::string sPlatformPriority;
-	std::vector<unsigned int> vLanguagePriority;
-	std::vector<unsigned int> vPlatformPriority;
+        std::string sFileIdString;
+        std::string sLanguagePriority;
+        std::string sPlatformPriority;
+        std::vector<unsigned int> vLanguagePriority;
+        std::vector<unsigned int> vPlatformPriority;
 
         unsigned int iInstallerType;
         unsigned int iInstallerLanguage;
