@@ -28,6 +28,7 @@
 #include <json/json.h>
 #include <ctime>
 #include <fstream>
+#include <deque>
 
 class Timer
 {
@@ -67,10 +68,13 @@ class Downloader
         void checkOrphans();
         void checkStatus();
         void updateCache();
+        void downloadFileWithId(const std::string& fileid_string);
+        void showWishlist();
         CURL* curlhandle;
         Timer timer;
         Config config;
         ProgressBar* progressbar;
+        std::deque< std::pair<time_t, size_t> > TimeAndSize;
     protected:
     private:
         CURLcode downloadFile(const std::string& url, const std::string& filepath, const std::string& xml_data = std::string(), const std::string& gamename = std::string());
@@ -89,9 +93,9 @@ class Downloader
         int HTTP_Login(const std::string& email, const std::string& password);
         std::vector<gameItem> getGames();
         std::vector<gameItem> getFreeGames();
-        std::vector<gameFile> getExtrasFromHTML(const std::string& html, const std::string& gamename, const std::string& gameid);
-        std::string getGameDetailsHTML(const std::string& gamename, const std::string& gameid);
-        std::string getSerialsFromHTML(const std::string& html);
+        std::vector<gameFile> getExtrasFromJSON(const Json::Value& json, const std::string& gamename);
+        Json::Value getGameDetailsJSON(const std::string& gameid);
+        std::string getSerialsFromJSON(const Json::Value& json);
         void saveSerials(const std::string& serials, const std::string& filepath);
 
         static int progressCallback(void *clientp, double dltotal, double dlnow, double ultotal, double ulnow);
