@@ -17,6 +17,7 @@
 #include <sstream>
 #include <rhash.h>
 #include <boost/filesystem.hpp>
+#include <json/json.h>
 
 struct gameSpecificConfig
 {
@@ -37,6 +38,8 @@ namespace Util
     void filepathReplaceReservedStrings(std::string& str, const std::string& gamename, const unsigned int& platformId = 0, const std::string& dlcname = "");
     void setFilePermissions(const boost::filesystem::path& path, const boost::filesystem::perms& permissions);
     int getTerminalWidth();
+    void getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls);
+    std::vector<std::string> getDLCNamesFromJSON(const Json::Value &root);
 }
 
 #endif // UTIL_H
